@@ -1,4 +1,4 @@
-# $Id: Config.pm 43956 2015-10-02 13:25:27Z wsl $
+# $Id: Config.pm 37839 2012-09-17 09:33:01Z wsl $
 # $URL: https://svn.uvt.nl/its-id/trunk/sources/aselect-perl/lib/Aselect/Config.pm $
 
 use utf8;
@@ -37,7 +37,6 @@ field login_url => undef;
 field urlfilter => sub { qr{^} };
 field servicefilter => sub { qr{^} };
 field https_everywhere => undef;
-field lock_client_ip => 1;
 
 *set_aselectserverid = *id;
 *set_aselectorganization = *organization;
@@ -73,7 +72,7 @@ sub set_aselectattributes {
 	}
 	foreach my $attr (@_) {
 		my ($key, $val) = split(' ', $attr, 2);
-		push @{$attributes{$key}}, $val;
+		$attributes{$key} = $val;
 	}
 	$attributes->{$name} = \%attributes;
 }
@@ -121,7 +120,3 @@ sub set_aselectloginurl {
 	die "Invalid URL: '$url'\n" unless $url =~ m{^https?://[!-~]+$};
 	$self->login_url($url);
 }
-
-sub set_lockclientip {
-	$self->lock_client_ip(parse_bool(shift // 1));
-}
