@@ -1,4 +1,4 @@
-# $Id: Document.pm 47800 2018-09-27 12:12:37Z wsl $
+# $Id: Document.pm 36341 2012-01-15 18:20:01Z wsl $
 # $URL: https://svn.uvt.nl/its-id/trunk/sources/aselect-perl/lib/Aselect/UI/Document.pm $
 
 use strict;
@@ -24,17 +24,11 @@ sub transform {
 }
 
 sub build {
-	my $name = $self->rootname;
-	my $root = $self->construct($name);
-	$self->setDocumentElement($root);
-
 	$self->hook_next;
-
-	$root = $self->documentElement;
-	$name = $root->nodeName;
-
 	my $cfg = $self->cfg;
 	my $req = $self->req;
+	my $root = $self->documentElement;
+
 	$root->appendChild($self->construct(settings =>
 		[warn => $req->new_warn],
 		[remember => $req->new_remember],
@@ -47,15 +41,19 @@ sub build {
 	if(my $uid = $ticket->uid) {
 		my $exp = $ticket->expiration;
 
-		$root->appendChild($self->construct(session =>
+		my $session = $self->construct(session =>
 			[uid => $uid],
 			[organization => $cfg->organization],
-			[start => iso8601(gmtime($exp)) . ' GMT'],
-			[end => iso8601(gmtime($exp + $cfg->session_timeout)) . ' GMT'],
-		));
+			[start => iso8601(localtime($exp))],
+			[end => iso8601(localtime($exp + $cfg->session_timeout))],
+		);
+
+		$root->appendChild($session);
 	}
 
-	eval { $self->transform($name =~ tr|:|/|r) };
+	my $name = $root->nodeName;
+	$name =~ tr|:|/|;
+	eval { $self->transform($name) };
 	warn $@ if $@;
 }
 
@@ -79,9 +77,6 @@ sub response {
 		$res->setcookie($cookie);
 	}
 
-	# intermediate proxies should not cache any page
-	$res->addheader('Cache-Control' => 'private');
-
 	my $sts = $self->cfg->strict_transport_security;
 	$res->setheader('Strict-Transport-Security' => "max-age=$sts")
 		if $sts && $req->https eq 'on';
@@ -92,6 +87,9 @@ sub response {
 	# Don't try to second guess the content type
 	$res->setheader('X-Content-Type-Options' => 'nosniff');
 
+	# Protect against clickjacking
+	$res->setheader('X-Frame-Options' => 'DENY');
+
 	$res->mimetype('application/xml')
 		if $req->raw;
 
