@@ -1,4 +1,4 @@
-# $Id: Error.pm 42424 2014-10-22 12:12:06Z wsl $
+# $Id: Error.pm 36089 2011-11-23 19:23:06Z wsl $
 # $URL: https://svn.uvt.nl/its-id/trunk/sources/aselect-perl/lib/Aselect/UI/Error.pm $
 
 use strict;
@@ -9,14 +9,12 @@ package Aselect::UI::Error;
 
 use Aselect::UI::Document -self;
 
-use constant rootname => 'error';
-
 field type;
 field args;
 
 sub build {
-	my $root = $self->documentElement;
-	$root->appendChild($self->construct(code => $self->type));
+	my $root = $self->construct('error', [code => $self->type]);
+	$self->setDocumentElement($root);
 	my $args = $self->args;
 	if(%$args) {
 		my $arglist = $self->construct('args');
