@@ -1,4 +1,4 @@
-# $Id: Request.pm 38478 2013-01-14 11:39:21Z wsl $
+# $Id: Request.pm 39120 2013-03-21 15:33:11Z wsl $
 # $URL: https://svn.uvt.nl/its-id/trunk/sources/aselect-perl/lib/Aselect/UI/Login/Request.pm $
 
 use strict;
@@ -70,10 +70,8 @@ field effective_warn => sub {
 field effective_remember => sub {
 	my $self = shift;
 	return 'true' unless defined $self->rid || defined $self->service;
-	if($self->nonce) {
-		my $remember = $self->bool_param('remember');
-		return bool_string($remember) if defined $remember;
-	}
+	return bool_string($self->bool_param('remember') // 0)
+		if $self->nonce;
 	return $self->new_remember;
 };
 
