@@ -1,4 +1,4 @@
-# $Id: Confirm.pm 42301 2014-09-26 14:37:50Z wsl $
+# $Id: Confirm.pm 35785 2011-10-17 15:25:15Z wsl $
 # $URL: https://svn.uvt.nl/its-id/trunk/sources/aselect-perl/lib/Aselect/UI/Logout/Confirm.pm $
 
 use strict;
@@ -9,14 +9,13 @@ package Aselect::UI::Logout::Confirm;
 
 use Aselect::UI::Document -self;
 
-use constant rootname => 'confirm-logout';
-
 sub build {
 	my $req = $self->req;
 
 	my $logout = $self->construct('logout' =>
 		[warn => $req->effective_warn],
 	);
+	$self->setDocumentElement($self->construct('confirm-logout' => $logout));
 
 	if(my $service = $req->service) {
 		$logout->appendTextChild(service => $service);
@@ -25,6 +24,4 @@ sub build {
 	if(my $url = $req->back_url) {
 		$logout->appendTextChild(url => $url);
 	}
-
-	$self->documentElement->appendChild($logout);
 }
