@@ -1,4 +1,4 @@
-# $Id: Request.pm 39148 2013-03-27 14:48:15Z wsl $
+# $Id: Request.pm 37889 2012-09-28 10:04:21Z wsl $
 # $URL: https://svn.uvt.nl/its-id/trunk/sources/aselect-perl/lib/Aselect/UI/Password/Request.pm $
 
 use strict;
@@ -32,9 +32,7 @@ const uid => sub {
 
 	my $uid = eval { $self->dir->authenticate($username, $password) };
 	die $self->errorpage('backend', $@, username => $username) if $@;
-	if(defined $uid) {
-		warn "Successfully authenticated as '$uid' using password\n";
-	} else {
+	unless(defined $uid) {
 		$self->message('credentials');
 		sleep($self->cfg->authfail_timeout);
 	}
